summaryrefslogtreecommitdiffstats
path: root/src/querypagebase.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:13:25 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:53 +0200
commit84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (patch)
tree770861aa9033e1dc6c5168358194ff85b32dd429 /src/querypagebase.cpp
parent57d8bb3d12aed373eee08915f0ff19f5233aabe3 (diff)
downloadkscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.tar.gz
kscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.zip
Initial TQt conversion
Diffstat (limited to 'src/querypagebase.cpp')
-rw-r--r--src/querypagebase.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/querypagebase.cpp b/src/querypagebase.cpp
index 08cbe6d..8af1872 100644
--- a/src/querypagebase.cpp
+++ b/src/querypagebase.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <qfile.h>
+#include <ntqfile.h>
#include "querypagebase.h"
#include "queryview.h"
#include "kscopeconfig.h"
@@ -37,8 +37,8 @@
* @param pParent The parent widget
* @param szName The widget's name
*/
-QueryPageBase::QueryPageBase(QWidget* pParent, const char* szName) :
- QHBox(pParent, szName),
+QueryPageBase::QueryPageBase(TQWidget* pParent, const char* szName) :
+ TQHBox(pParent, szName),
m_bLocked(false)
{
}
@@ -70,20 +70,20 @@ void QueryPageBase::applyPrefs()
* @param sFileName The name of the query file to load
* @return true if successful, false otherwise
*/
-bool QueryPageBase::load(const QString& sProjPath, const QString& sFileName)
+bool QueryPageBase::load(const TQString& sProjPath, const TQString& sFileName)
{
- QString sTemp, sFile, sFunc, sLine, sText;
+ TQString sTemp, sFile, sFunc, sLine, sText;
int nState;
// Try to open the query file for reading
- QFile file(sProjPath + "/" + sFileName);
+ TQFile file(sProjPath + "/" + sFileName);
if (!file.open(IO_ReadOnly))
return false;
{
// Use a new scope for the QTextStream object, to ensure its
// destruction before the file is deleted
- QTextStream str(&file);
+ TQTextStream str(&file);
// Make sure the file's version is correct
sTemp = str.readLine();
@@ -99,7 +99,7 @@ bool QueryPageBase::load(const QString& sProjPath, const QString& sFileName)
// Read query records
sTemp = str.readLine();
nState = 0;
- while (sTemp != QString::null) {
+ while (sTemp != TQString::null) {
switch (nState) {
// File path
case 0:
@@ -143,9 +143,9 @@ bool QueryPageBase::load(const QString& sProjPath, const QString& sFileName)
* return
* @return true if successful, false otherwise
*/
-bool QueryPageBase::save(const QString& sProjPath, QString& sFileName)
+bool QueryPageBase::save(const TQString& sProjPath, TQString& sFileName)
{
- QListViewItemIterator itr(m_pView);
+ TQListViewItemIterator itr(m_pView);
// Get the file name to use
sFileName = getFileName(sProjPath);
@@ -153,11 +153,11 @@ bool QueryPageBase::save(const QString& sProjPath, QString& sFileName)
return false;
// Open the query file for writing
- QFile file(sProjPath + "/" + sFileName);
+ TQFile file(sProjPath + "/" + sFileName);
if (!file.open(IO_WriteOnly))
return false;
- QTextStream str(&file);
+ TQTextStream str(&file);
// Write the version string
str << FILE_VERSION << "\n";
@@ -70,20 +70,20 @@ void QueryPageBase::applyPrefs()
return false;
{
- // Use a new scope for the QTextStream object, to ensure its
+ // Use a new scope for the TQTextStream object, to ensure its
// destruction before the file is deleted